<?php
/**
 * Popular post Section options
 *
 * @package Theme Palace
 * @subpackage Magpaper Pro
 * @since Magpaper Pro 1.0.0
 */

// Add Popular post section
$wp_customize->add_section( 'magpaper_pro_popular_post_section', array(
	'title'             => esc_html__( 'Popular Posts','magpaper-pro' ),
	'description'       => esc_html__( 'Popular Posts Section options.', 'magpaper-pro' ),
	'panel'             => 'magpaper_pro_front_page_panel',
) );

// Popular post content enable control and setting
$wp_customize->add_setting( 'magpaper_pro_theme_options[popular_post_section_enable]', array(
	'default'			=> 	$options['popular_post_section_enable'],
	'sanitize_callback' => 'magpaper_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Magpaper_Pro_Switch_Control( $wp_customize, 'magpaper_pro_theme_options[popular_post_section_enable]', array(
	'label'             => esc_html__( 'Popular posts Section Enable', 'magpaper-pro' ),
	'section'           => 'magpaper_pro_popular_post_section',
	'on_off_label' 		=> magpaper_pro_switch_options(),
) ) );

// Popular post content 
$wp_customize->add_setting( 'magpaper_pro_theme_options[popular_post_title]',
	array(
		'default'       	=> $options['popular_post_title'],
		'sanitize_callback'	=> 'sanitize_text_field',
		'transport'			=> 'postMessage',
	)
);
$wp_customize->add_control( 'magpaper_pro_theme_options[popular_post_title]',
    array(
		'label'      		=> esc_html__( 'Popular Posts Title', 'magpaper-pro' ),
		'section'    		=> 'magpaper_pro_popular_post_section',
		'type'		 		=> 'text',
		'active_callback'   => 'magpaper_pro_is_popular_post_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magpaper_pro_theme_options[popular_post_title]', array(
		'selector'            => '#popular-posts .section-header h2.section-title',
		'settings'            => 'magpaper_pro_theme_options[popular_post_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'magpaper_pro_popular_post_title_partial',
    ) );
}

// Popular post right control and setting
$wp_customize->add_setting( 'magpaper_pro_theme_options[popular_post_right_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Magpaper_Pro_Note_Control( $wp_customize, 'magpaper_pro_theme_options[popular_post_right_label]', array(
	'label'             => esc_html__( 'Highlighted Post', 'magpaper-pro' ),
	'section'           => 'magpaper_pro_popular_post_section',
	'active_callback'	=> 'magpaper_pro_is_popular_post_section_enable',
) ) );

// Popular post highlighted content type control and setting
$wp_customize->add_setting( 'magpaper_pro_theme_options[popular_post_right_content_type]', array(
	'default'          	=> $options['popular_post_right_content_type'],
	'sanitize_callback' => 'magpaper_pro_sanitize_select',
) );

$wp_customize->add_control( 'magpaper_pro_theme_options[popular_post_right_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'magpaper-pro' ),
	'section'           => 'magpaper_pro_popular_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'magpaper_pro_is_popular_post_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'magpaper-pro' ),
		'post' 		=> esc_html__( 'Post', 'magpaper-pro' ),
	),
) );

// popular_post pages drop down chooser control and setting
$wp_customize->add_setting( 'magpaper_pro_theme_options[popular_post_right_content_page]', array(
	'sanitize_callback' => 'magpaper_pro_sanitize_page',
) );

$wp_customize->add_control( new Magpaper_Pro_Dropdown_Chooser( $wp_customize, 'magpaper_pro_theme_options[popular_post_right_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'magpaper-pro' ),
	'section'           => 'magpaper_pro_popular_post_section',
	'choices'			=> magpaper_pro_page_choices(),
	'active_callback'	=> 'magpaper_pro_is_popular_post_right_section_content_page_enable',
) ) );

// popular_post posts drop down chooser control and setting
$wp_customize->add_setting( 'magpaper_pro_theme_options[popular_post_right_content_post]', array(
	'sanitize_callback' => 'magpaper_pro_sanitize_page',
) );

$wp_customize->add_control( new Magpaper_Pro_Dropdown_Chooser( $wp_customize, 'magpaper_pro_theme_options[popular_post_right_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'magpaper-pro' ),
	'section'           => 'magpaper_pro_popular_post_section',
	'choices'			=> magpaper_pro_post_choices(),
	'active_callback'	=> 'magpaper_pro_is_popular_post_right_section_content_post_enable',
) ) );




// Popular post left control and setting
$wp_customize->add_setting( 'magpaper_pro_theme_options[popular_post_left_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Magpaper_Pro_Note_Control( $wp_customize, 'magpaper_pro_theme_options[popular_post_left_label]', array(
	'label'             => esc_html__( 'Popular Posts', 'magpaper-pro' ),
	'section'           => 'magpaper_pro_popular_post_section',
	'active_callback'	=> 'magpaper_pro_is_popular_post_section_enable',
) ) );

// Popular post count control and setting
$wp_customize->add_setting( 'magpaper_pro_theme_options[popular_post_count]', array(
	'default'          	=> $options['popular_post_count'],
	'sanitize_callback' => 'magpaper_pro_sanitize_number_range',
	'validate_callback' => 'magpaper_pro_validate_popular_post_count',
) );

$wp_customize->add_control( 'magpaper_pro_theme_options[popular_post_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'magpaper-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'magpaper-pro' ),
	'section'           => 'magpaper_pro_popular_post_section',
	'active_callback'   => 'magpaper_pro_is_popular_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

// Popular post content type control and setting
$wp_customize->add_setting( 'magpaper_pro_theme_options[popular_post_left_content_type]', array(
	'default'          	=> $options['popular_post_left_content_type'],
	'sanitize_callback' => 'magpaper_pro_sanitize_select',
) );

$wp_customize->add_control( 'magpaper_pro_theme_options[popular_post_left_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'magpaper-pro' ),
	'section'           => 'magpaper_pro_popular_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'magpaper_pro_is_popular_post_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'magpaper-pro' ),
		'post' 		=> esc_html__( 'Post', 'magpaper-pro' ),
		'category' 	=> esc_html__( 'Category', 'magpaper-pro' ),
	),
) );

for ( $i = 1; $i <= $options['popular_post_count']; $i++ ) {
	// popular_post pages drop down chooser control and setting
	$wp_customize->add_setting( 'magpaper_pro_theme_options[popular_post_left_content_page_' . $i . ']', array(
		'sanitize_callback' => 'magpaper_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Magpaper_Pro_Dropdown_Chooser( $wp_customize, 'magpaper_pro_theme_options[popular_post_left_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'magpaper-pro' ), $i ),
		'section'           => 'magpaper_pro_popular_post_section',
		'choices'			=> magpaper_pro_page_choices(),
		'active_callback'	=> 'magpaper_pro_is_popular_post_left_section_content_page_enable',
	) ) );

	// popular_post posts drop down chooser control and setting
	$wp_customize->add_setting( 'magpaper_pro_theme_options[popular_post_left_content_post_' . $i . ']', array(
		'sanitize_callback' => 'magpaper_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Magpaper_Pro_Dropdown_Chooser( $wp_customize, 'magpaper_pro_theme_options[popular_post_left_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'magpaper-pro' ), $i ),
		'section'           => 'magpaper_pro_popular_post_section',
		'choices'			=> magpaper_pro_post_choices(),
		'active_callback'	=> 'magpaper_pro_is_popular_post_left_section_content_post_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'magpaper_pro_theme_options[popular_post_left_content_category]', array(
	'sanitize_callback' => 'magpaper_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Magpaper_Pro_Dropdown_Taxonomies_Control( $wp_customize,'magpaper_pro_theme_options[popular_post_left_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'magpaper-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no. of posts will be shown from selected category', 'magpaper-pro' ),
	'section'           => 'magpaper_pro_popular_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'magpaper_pro_is_popular_post_left_section_content_category_enable'
) ) );


